
#line 3 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart (FILE *input_file ,yyscan_t yyscanner );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void yypop_buffer_state (yyscan_t yyscanner );

static void yyensure_buffer_stack (yyscan_t yyscanner );
static void yy_load_buffer_state (yyscan_t yyscanner );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len ,yyscan_t yyscanner );

void *yyalloc (yy_size_t ,yyscan_t yyscanner );
void *yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 183
#define YY_END_OF_BUFFER 184
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[675] =
    {   0,
        0,    0,  184,  182,  180,  179,  182,  182,  152,  178,
      154,  154,  154,  154,  152,  152,  152,  152,  152,  152,
      152,  152,  152,  152,  152,  152,  152,  152,  152,  152,
      152,  152,  152,  152,  180,    0,    0,  181,  152,    0,
      153,  155,  175,  175,    0,    0,    0,    0,  175,    0,
        0,    0,    0,    0,    0,    0,  132,  176,  133,  134,
      166,  166,  166,  166,    0,  154,    0,  140,  141,  142,
      152,  152,  152,  152,  152,  152,  152,  152,  152,  152,
      152,  152,  152,  152,  152,  152,  152,  152,  152,  152,
      152,  152,  152,  152,  152,  152,  152,  152,  152,  152,

      152,  152,  152,  152,  152,  152,  152,  152,  152,  152,
      152,  152,  152,  152,  152,  152,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  174,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  173,  173,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      172,  172,  172,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  163,  163,  163,  164,  164,  165,  156,
      155,  156,    0,  157,   11,   13,  152,   15,  152,  152,
       16,   18,  152,   20,   22,   24,   26,    6,   28,   30,
       31,   33,   35,   38,   36,   40,   41,   43,   45,   47,

       49,   51,  152,  152,  152,   53,   55,  152,   57,   59,
       61,  152,   63,   65,   67,   69,  152,   71,   73,   75,
       77,  152,  152,  152,  152,  152,  152,    0,    0,    0,
        0,  155,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   93,   94,   96,    0,  171,    0,    0,    0,
        0,    0,    0,  110,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  170,  169,  169,  122,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  160,  160,
      161,  162,    0,  158,  152,  152,  152,  152,  152,  152,
      152,  152,  143,  152,  152,  152,  152,  152,  152,  152,

      152,  152,  152,  152,  152,  152,  152,  152,  152,  152,
      152,  152,  152,  144,  152,  152,  152,  152,  152,  152,
      152,  152,   10,  152,  152,  152,  152,  152,  152,  152,
      152,  152,  152,    0,  177,    0,    0,    0,   86,   87,
        0,    0,    0,    0,    0,    0,    0,   98,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  168,    0,    0,    0,
      126,    0,  128,    0,    0,    0,    0,    0,    0,  167,
      159,  152,  152,  152,    4,  152,  152,  152,  152,  152,
      152,  152,  152,  152,  152,  152,  152,  152,  152,  152,

      152,  152,  152,  152,  152,  152,    9,  152,  152,  152,
      152,  152,  152,  152,  152,  152,  152,  152,  152,  152,
      152,  152,  152,  152,   82,  152,  152,    0,    0,    0,
        0,    0,   88,   89,    0,    0,    0,    0,   97,    0,
        0,  101,  104,    0,    0,    0,    0,    0,    0,    0,
      115,  116,    0,    0,    0,    0,  121,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  152,  152,  152,
      152,  152,  152,    5,  152,  152,  152,  152,  152,  152,
      152,  152,  152,  152,  152,  152,  152,  152,  152,  152,
      152,    7,    8,  152,  152,  152,  152,  152,  152,  152,

      152,  152,  152,  152,  152,  152,  152,  152,  152,   83,
      152,   79,    0,    0,    0,    0,  137,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  107,    0,  111,  112,
        0,  114,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  130,  131,    0,    0,  138,   12,    3,   14,
      148,  149,  152,   17,   19,   21,   23,   25,   27,   29,
       32,   34,   39,   37,   42,   44,   46,   48,   50,   52,
       54,   56,   58,   60,   62,  152,  152,  152,   64,   66,
       68,   70,   72,   74,   76,   78,  152,   81,  139,    0,
        0,   84,    0,   90,    0,    0,    0,   99,    0,    0,

        0,    0,    0,    0,  113,    0,    0,  119,  106,    0,
        0,    0,    0,    0,    0,  135,    0,  152,  145,  146,
      152,   80,    0,    0,    0,    0,   92,   95,  100,    0,
        0,  105,    0,    0,    0,  118,    0,    0,    0,    0,
      127,  129,    0,  152,  152,    2,    1,    0,   91,    0,
      103,    0,  109,  117,    0,    0,  124,  125,  136,  152,
      147,    0,  102,    0,  120,  123,  152,   85,  108,  152,
      152,  150,  151,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    1,    6,    7,    1,    1,    1,    1,
        1,    1,    8,    1,    8,    9,    1,   10,   11,   12,
       13,   14,   15,   15,   15,   15,   15,    1,    1,    1,
        1,    1,    1,    1,   16,   17,   18,   19,   20,   21,
       22,   23,   24,    7,   25,   26,   27,   28,   29,   30,
       31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
        1,    1,    1,    1,   41,    1,   42,   43,   44,   45,

       46,   47,   48,   49,   50,   51,   52,   53,   54,   55,
       56,   57,   58,   59,   60,   61,   62,   63,   64,   65,
       66,   67,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[68] =
    {   0,
        1,    1,    1,    1,    1,    1,    2,    1,    3,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2
    } ;

static yyconst flex_int16_t yy_base[678] =
    {   0,
        0,    0,  954,  955,   66,  955,  948,  949,    0,   69,
       85,  128,  140,  152,  151,   58,   39,   48,   75,  927,
      158,  160,   73,   59,   71,  170,   54,  920,  890,  889,
      901,  885,  899,  898,  142,  927,  939,  955,    0,  206,
      955,  189,  168,  171,   53,   27,   66,  119,  175,  899,
      885,  123,  170,  883,  895,  183,  955,  198,  225,   99,
      212,  219,  223,  227,  285,  297,  308,  955,  955,  955,
      904,  917,  911,  165,  900,  903,  899,  914,  224,  896,
      910,  194,  896,  909,  900,  913,  890,  901,  892,  294,
      893,  884,  893,  884,  883,  884,  878,  884,  895,  881,

      878,  890,  893,  880,  873,  889,  865,  193,  139,  885,
      861,  846,  841,  858,  834,  839,  865,  167,  854,  259,
      849,  325,  282,  851,  832,  302,  842,  838,  833,   43,
      839,  825,  841,  838,  829,  305,  309,  831,  820,  834,
      837,  819,  834,  821,  818,  825,  275,  833,  254,  299,
      317,  327,  331,  810,  827,  828,  821,  803,  310,  804,
      826,  817,  316,  327,  331,  335,  339,  343,  347,  955,
      405,  416,  422,  428,  825,  240,  849,    0,  848,  831,
      821,  820,  840,  818,  817,  816,  815,    0,  814,    0,
      813,  812,    0,  811,  810,    0,  809,  808,  807,  806,

      805,  804,  820,  813,  826,  800,  799,  805,  797,  796,
      795,  816,  793,  792,  791,  790,  800,  788,  787,  786,
      785,  777,  776,  761,  761,  760,  759,  802,  774,  762,
      434,  442,  416,  766,  186,  763,  757,  757,  751,  764,
      764,  749,  955,  955,  764,  752,  418,  759,  281,  756,
      762,  308,  757,  955,  748,  755,  754,  757,  743,  742,
      746,  741,  278,  746,  420,  428,  430,  955,  738,  736,
      736,  744,  745,  727,  421,  732,  738,  419,  426,  430,
      434,  438,  496,  502,  752,  764,  750,  749,  742,  756,
      746,  745,    0,  744,  743,  742,  741,  740,  739,  738,

      737,  736,  735,  734,  733,  732,  731,  730,  733,  726,
      733,  726,  725,    0,  724,  723,  722,  725,  720,  719,
      718,  717,    0,  716,  715,  714,  713,  691,  685,  690,
      696,  679,  694,  315,  955,  693,  683,  687,  955,  955,
      677,  686,  672,  689,  672,  675,  669,  955,  670,  669,
      666,  673,  666,  674,  670,  680,  677,  659,  665,  672,
      656,  655,  673,  655,  667,  666,  955,  665,  655,  659,
      955,  646,  955,  651,  651,  659,  642,  643,  653,  955,
      955,  685,  667,  683,    0,  507,  681,  681,  680,  679,
      678,  677,  676,  675,  674,  673,  672,  671,  670,  669,

      668,  667,  666,  665,  652,  645,    0,  662,  661,  660,
      659,  658,  636,  656,  655,  654,  653,  652,  651,  650,
      649,  618,  621,  601,    0,  602,  595,  602,  601,  602,
      594,  612,  955,  955,  594,  592,  602,  595,  955,  590,
      607,  330,  955,  598,  582,  583,  592,  583,  582,  582,
      955,  581,  590,  580,  596,  593,  955,  592,  590,  579,
      580,  576,  568,  575,  570,  571,  566,  592,  592,  590,
      604,  603,  598,    0,  586,  585,  584,  583,  582,  581,
      580,  579,  578,  577,  576,  575,  574,  573,  572,  571,
      570,    0,    0,  569,  568,  567,  566,  565,  509,  564,

      563,  562,  561,  560,  559,  558,  557,  535,  535,    0,
      542,    0,  576,  575,  524,  542,  955,  537,  532,  525,
      521,  533,  523,  521,  517,  533,  524,  523,  955,  955,
      526,  955,  521,  514,  503,  514,  506,  510,  523,  518,
      521,  503,  955,  955,  515,  504,  955,    0,    0,    0,
        0,    0,  543,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  539,  538,  536,    0,    0,
        0,    0,    0,    0,    0,    0,  494,    0,    0,  545,
      544,  955,  491,  955,  495,  495,  504,  955,  488,  502,

      483,  485,  482,  490,  955,  468,  479,  955,  955,  483,
      479,  472,  470,  470,  483,  955,  467,  507,    0,    0,
      507,    0,  514,  513,  472,  433,  955,  955,  955,  435,
      435,  955,  429,  386,  377,  955,  366,  365,  323,  328,
      955,  955,  339,  348,  337,  955,  955,  307,  955,  305,
      955,  257,  955,  955,  247,  221,  955,  955,  955,  236,
        0,  213,  955,  150,  955,  955,  232,  955,  955,  162,
      138,    0,    0,  955,  541,  108,  544
    } ;

static yyconst flex_int16_t yy_def[678] =
    {   0,
      674,    1,  674,  674,  674,  674,  674,  675,  676,  674,
      674,  674,  674,  674,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  674,  674,  675,  674,  676,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  677,  674,  674,  674,  674,  674,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,

      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,

      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,

      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,

      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,

      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,

      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  676,  676,  676,
      676,  676,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  676,  676,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  676,
      676,  674,  674,  674,  674,  674,  676,  674,  674,  676,
      676,  676,  676,    0,  674,  674,  674
    } ;

static yyconst flex_int16_t yy_nxt[1023] =
    {   0,
        4,    5,    6,    5,    7,    8,    9,    4,   10,   11,
       12,   13,   14,   11,   11,   15,    9,   16,   17,   18,
       19,    9,    9,    9,   20,   21,   22,    9,   23,   24,
        9,   25,   26,   27,    9,    9,    9,   28,    9,    9,
        9,    9,    9,    9,    9,    9,   29,    9,    9,    9,
        9,    9,    9,    9,    9,    9,   30,    9,   31,   32,
       33,    9,   34,    9,    9,    9,    9,   35,   79,   35,
       40,   80,  129,  108,   96,   81,  130,   41,   42,   42,
       42,   42,   42,   42,   76,   82,   77,   97,   98,  240,
       99,  109,   78,   65,   66,   66,   66,   66,   66,   66,

       83,  241,   94,  100,   67,  127,   84,   95,  128,   39,
       43,   44,   45,   46,   47,   48,   49,   50,   51,  131,
      132,   52,   53,   54,   55,   56,   57,   58,   59,   60,
       67,  133,   61,   62,   63,   64,   65,   66,   66,   66,
       66,   66,   66,   35,  160,   35,   68,   67,   65,   66,
       66,   66,   66,   66,   66,  219,  673,  161,   69,   67,
       65,   66,   66,   66,   66,   66,   66,   71,  220,   72,
       70,   67,  140,   67,  134,   90,   73,  135,  141,   86,
      672,   87,   74,   91,   75,   67,   88,  101,   92,   89,
      178,  102,  103,  104,   93,  105,  179,   67,   42,   42,

       42,   42,   42,   42,  106,  189,  107,   40,  122,  123,
      123,  142,  126,  123,  669,  123,  136,  137,  123,  217,
      124,  124,  123,  190,  147,  143,  123,  125,  125,  123,
      218,  337,  144,  123,  122,  148,  184,  185,  149,  151,
      152,  150,  670,  671,  338,  153,  186,  118,  119,   45,
       46,   47,   48,  154,   50,   51,  123,  162,   52,   53,
       54,   55,   56,   57,  120,   59,   60,  668,  155,  121,
      156,  286,  667,  157,  158,  163,  163,  163,  163,  666,
      287,  159,  164,  163,  165,  166,  167,  163,  163,  168,
      169,  163,  163,  163,  171,  171,  171,  171,  171,  171,

      230,  665,  664,  260,  172,   65,   66,   66,   66,   66,
       66,   66,  198,  261,  154,  173,   67,  174,  174,  174,
      174,  174,  174,  233,  233,  364,  349,  257,  365,  233,
      172,  199,  231,  258,  232,  232,  232,  232,  232,  232,
      233,  350,   67,  233,  233,  236,  233,  233,  262,  233,
      247,  233,  233,  353,  263,  273,  233,  663,  233,  233,
      233,  428,  662,  233,  233,  274,  354,  233,  265,  233,
      661,  264,  266,  267,  233,  233,  660,  429,  233,  278,
      278,  278,  278,  524,  659,  233,  525,  658,  657,  233,
      278,  278,  278,  278,  279,  278,  278,  280,  281,  278,

      278,  278,  278,  278,  278,  278,  282,  278,  278,  278,
      278,  278,  278,  278,   42,   42,   42,   42,   42,   42,
      656,  655,  654,  283,  122,  284,  284,  284,  284,  284,
      284,  174,  174,  174,  174,  174,  174,  174,  174,  174,
      174,  174,  174,  232,  232,  232,  232,  232,  232,  653,
      122,  232,  232,  232,  232,  232,  232,  335,  335,  335,
      335,  335,  335,  335,  374,  335,  375,  335,  376,  335,
      335,  367,  335,  652,  335,  335,  335,  335,  335,  651,
      650,  377,  380,  380,  380,  380,  335,  649,  335,  380,
      380,  380,  380,  381,  380,  380,  380,  380,  380,  380,

      380,  380,  380,  380,  380,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  471,  472,  576,
      577,  648,  647,  646,  645,  644,  643,  642,  641,  640,
      639,  638,  637,  636,  635,  634,  633,  632,  631,  473,
      578,   37,   37,   37,  170,  170,  630,  629,  628,  627,
      626,  625,  624,  623,  622,  621,  620,  619,  618,  617,
      616,  615,  614,  613,  612,  611,  610,  609,  608,  607,
      606,  605,  604,  603,  602,  601,  600,  599,  598,  597,
      596,  595,  594,  593,  592,  591,  590,  589,  588,  587,
      586,  585,  584,  583,  582,  581,  580,  579,  575,  574,

      573,  572,  571,  570,  569,  568,  567,  566,  565,  564,
      563,  562,  561,  560,  559,  558,  557,  556,  555,  554,
      553,  552,  551,  550,  549,  548,  547,  546,  545,  544,
      543,  542,  541,  540,  539,  538,  537,  536,  535,  534,
      533,  532,  531,  530,  529,  528,  527,  526,  523,  522,
      521,  520,  519,  518,  517,  516,  515,  514,  513,  512,
      511,  510,  509,  508,  507,  506,  505,  504,  503,  502,
      501,  500,  499,  498,  497,  496,  495,  494,  493,  492,
      491,  490,  489,  488,  487,  486,  485,  484,  483,  482,
      481,  480,  479,  478,  477,  476,  475,  474,  470,  469,

      468,  467,  466,  465,  464,  463,  462,  461,  460,  459,
      458,  457,  456,  455,  454,  453,  452,  451,  450,  449,
      448,  447,  446,  445,  444,  443,  442,  441,  440,  439,
      438,  437,  436,  435,  434,  433,  432,  431,  430,  427,
      426,  425,  424,  423,  422,  421,  420,  419,  418,  417,
      416,  415,  414,  413,  412,  411,  410,  409,  408,  407,
      406,  405,  404,  403,  402,  401,  400,  399,  398,  397,
      396,  395,  394,  393,  392,  391,  390,  389,  388,  387,
      386,  385,  384,  383,  382,  379,  378,  373,  372,  371,
      370,  369,  368,  366,  363,  362,  361,  360,  359,  358,

      357,  356,  355,  352,  351,  348,  347,  346,  345,  344,
      343,  342,  341,  340,  339,  336,  264,  236,  334,  333,
      332,  331,  330,  329,  328,  327,  326,  325,  324,  323,
      322,  321,  320,  319,  318,  317,  316,  315,  314,  313,
      312,  311,  310,  309,  308,  307,  306,  305,  304,  303,
      302,  301,  300,  299,  298,  297,  296,  295,  294,  293,
      292,  291,  290,  289,  288,  285,  277,  276,  275,  272,
      271,  270,  269,  268,  259,  256,  255,  254,  253,  252,
      251,  250,  249,  248,  246,  245,  244,  243,  242,  239,
      238,  237,  235,  234,  162,  229,  228,  227,  226,  225,

      224,  223,  222,  221,  216,  215,  214,  213,  212,  211,
      210,  209,  208,  207,  206,  205,  204,  203,  202,  201,
      200,  197,  196,  195,  194,  193,  192,  191,  188,  187,
      183,  182,  181,  180,  177,  176,  175,  146,  145,  139,
      138,   38,  117,  116,  115,  114,  113,  112,  111,  110,
       85,   38,   36,  674,    3,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,

      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674
    } ;

static yyconst flex_int16_t yy_chk[1023] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    5,   17,    5,
       10,   17,   46,   27,   24,   18,   46,   10,   10,   10,
       10,   10,   10,   10,   16,   18,   16,   24,   25,  130,
       25,   27,   16,   11,   11,   11,   11,   11,   11,   11,

       19,  130,   23,   25,   11,   45,   19,   23,   45,  676,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   47,
       47,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       11,   47,   10,   10,   10,   10,   12,   12,   12,   12,
       12,   12,   12,   35,   60,   35,   12,   12,   13,   13,
       13,   13,   13,   13,   13,  109,  671,   60,   13,   13,
       14,   14,   14,   14,   14,   14,   14,   15,  109,   15,
       14,   14,   52,   12,   48,   22,   15,   48,   52,   21,
      670,   21,   15,   22,   15,   13,   21,   26,   22,   21,
       74,   26,   26,   26,   22,   26,   74,   14,   42,   42,

       42,   42,   42,   42,   26,   82,   26,   40,   42,   43,
       43,   53,   44,   44,  664,   43,   49,   49,   44,  108,
      118,   43,   49,   82,   56,   53,   43,  118,   43,   44,
      108,  235,   53,   49,   42,   56,   79,   79,   56,   58,
       58,   56,  667,  667,  235,   58,   79,   40,   40,   40,
       40,   40,   40,   58,   40,   40,   58,   61,   40,   40,
       40,   40,   40,   40,   40,   40,   40,  662,   59,   40,
       59,  176,  660,   59,   59,   61,   61,   61,   61,  656,
      176,   59,   62,   62,   62,   62,   63,   63,   63,   63,
       64,   64,   64,   64,   65,   65,   65,   65,   65,   65,

      120,  655,  652,  149,   65,   66,   66,   66,   66,   66,
       66,   66,   90,  149,  120,   67,   66,   67,   67,   67,
       67,   67,   67,  123,  123,  263,  249,  147,  263,  123,
       65,   90,  122,  147,  122,  122,  122,  122,  122,  122,
      123,  249,   66,  126,  126,  126,  136,  136,  150,  126,
      137,  137,  136,  252,  150,  159,  137,  650,  151,  151,
      126,  334,  648,  136,  151,  159,  252,  137,  152,  152,
      645,  151,  153,  153,  152,  151,  644,  334,  153,  163,
      163,  163,  163,  442,  643,  152,  442,  640,  639,  153,
      164,  164,  164,  164,  165,  165,  165,  165,  166,  166,

      166,  166,  167,  167,  167,  167,  168,  168,  168,  168,
      169,  169,  169,  169,  171,  171,  171,  171,  171,  171,
      638,  637,  635,  172,  171,  172,  172,  172,  172,  172,
      172,  173,  173,  173,  173,  173,  173,  174,  174,  174,
      174,  174,  174,  231,  231,  231,  231,  231,  231,  634,
      171,  232,  232,  232,  232,  232,  232,  233,  233,  247,
      247,  265,  265,  233,  275,  247,  275,  265,  275,  266,
      266,  267,  267,  633,  233,  266,  247,  267,  265,  631,
      630,  275,  278,  278,  278,  278,  266,  626,  267,  279,
      279,  279,  279,  280,  280,  280,  280,  281,  281,  281,

      281,  282,  282,  282,  282,  283,  283,  283,  283,  283,
      283,  284,  284,  284,  284,  284,  284,  386,  386,  499,
      499,  625,  624,  623,  621,  618,  617,  615,  614,  613,
      612,  611,  610,  607,  606,  604,  603,  602,  601,  386,
      499,  675,  675,  675,  677,  677,  600,  599,  597,  596,
      595,  593,  591,  590,  587,  578,  577,  576,  553,  546,
      545,  542,  541,  540,  539,  538,  537,  536,  535,  534,
      533,  531,  528,  527,  526,  525,  524,  523,  522,  521,
      520,  519,  518,  516,  515,  514,  513,  511,  509,  508,
      507,  506,  505,  504,  503,  502,  501,  500,  498,  497,

      496,  495,  494,  491,  490,  489,  488,  487,  486,  485,
      484,  483,  482,  481,  480,  479,  478,  477,  476,  475,
      473,  472,  471,  470,  469,  468,  467,  466,  465,  464,
      463,  462,  461,  460,  459,  458,  456,  455,  454,  453,
      452,  450,  449,  448,  447,  446,  445,  444,  441,  440,
      438,  437,  436,  435,  432,  431,  430,  429,  428,  427,
      426,  424,  423,  422,  421,  420,  419,  418,  417,  416,
      415,  414,  413,  412,  411,  410,  409,  408,  406,  405,
      404,  403,  402,  401,  400,  399,  398,  397,  396,  395,
      394,  393,  392,  391,  390,  389,  388,  387,  384,  383,

      382,  379,  378,  377,  376,  375,  374,  372,  370,  369,
      368,  366,  365,  364,  363,  362,  361,  360,  359,  358,
      357,  356,  355,  354,  353,  352,  351,  350,  349,  347,
      346,  345,  344,  343,  342,  341,  338,  337,  336,  333,
      332,  331,  330,  329,  328,  327,  326,  325,  324,  322,
      321,  320,  319,  318,  317,  316,  315,  313,  312,  311,
      310,  309,  308,  307,  306,  305,  304,  303,  302,  301,
      300,  299,  298,  297,  296,  295,  294,  292,  291,  290,
      289,  288,  287,  286,  285,  277,  276,  274,  273,  272,
      271,  270,  269,  264,  262,  261,  260,  259,  258,  257,

      256,  255,  253,  251,  250,  248,  246,  245,  242,  241,
      240,  239,  238,  237,  236,  234,  230,  229,  228,  227,
      226,  225,  224,  223,  222,  221,  220,  219,  218,  217,
      216,  215,  214,  213,  212,  211,  210,  209,  208,  207,
      206,  205,  204,  203,  202,  201,  200,  199,  198,  197,
      195,  194,  192,  191,  189,  187,  186,  185,  184,  183,
      182,  181,  180,  179,  177,  175,  162,  161,  160,  158,
      157,  156,  155,  154,  148,  146,  145,  144,  143,  142,
      141,  140,  139,  138,  135,  134,  133,  132,  131,  129,
      128,  127,  125,  124,  121,  119,  117,  116,  115,  114,

      113,  112,  111,  110,  107,  106,  105,  104,  103,  102,
      101,  100,   99,   98,   97,   96,   95,   94,   93,   92,
       91,   89,   88,   87,   86,   85,   84,   83,   81,   80,
       78,   77,   76,   75,   73,   72,   71,   55,   54,   51,
       50,   37,   36,   34,   33,   32,   31,   30,   29,   28,
       20,    8,    7,    3,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,

      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "program_lexer.l"
#line 2 "program_lexer.l"
/*
 * Copyright © 2009 Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
#include "main/glheader.h"
#include "main/imports.h"
#include "prog_instruction.h"
#include "prog_statevars.h"

#include "program_parser.h"
#include "program_parse.tab.h"

#define require_ARB_vp (yyextra->mode == ARB_vertex)
#define require_ARB_fp (yyextra->mode == ARB_fragment)
#define require_shadow (yyextra->option.Shadow)
#define require_rect   (yyextra->option.TexRect)
#define require_texarray        (yyextra->option.TexArray)

#ifndef HAVE_UNISTD_H
#define YY_NO_UNISTD_H
#endif

#define return_token_or_IDENTIFIER(condition, token)	\
   do {							\
      if (condition) {					\
	 return token;					\
      } else {						\
	 yylval->string = strdup(yytext);		\
	 return IDENTIFIER;				\
      }							\
   } while (0)

#define return_token_or_DOT(condition, token)		\
   do {							\
      if (condition) {					\
	 return token;					\
      } else {						\
	 yyless(1);					\
	 return DOT;					\
      }							\
   } while (0)


#define return_opcode(condition, token, opcode, sat)	\
   do {							\
      if (condition) {					\
	 yylval->temp_inst.Opcode = OPCODE_ ## opcode;	\
	 yylval->temp_inst.SaturateMode = SATURATE_ ## sat; \
	 return token;					\
      } else {						\
	 yylval->string = strdup(yytext);		\
	 return IDENTIFIER;				\
      }							\
   } while (0)

#define SWIZZLE_INVAL  MAKE_SWIZZLE4(SWIZZLE_NIL, SWIZZLE_NIL, \
				     SWIZZLE_NIL, SWIZZLE_NIL)

static unsigned
mask_from_char(char c)
{
   switch (c) {
   case 'x':
   case 'r':
      return WRITEMASK_X;
   case 'y':
   case 'g':
      return WRITEMASK_Y;
   case 'z':
   case 'b':
      return WRITEMASK_Z;
   case 'w':
   case 'a':
      return WRITEMASK_W;
   }

   return 0;
}

static unsigned
swiz_from_char(char c)
{
   switch (c) {
   case 'x':
   case 'r':
      return SWIZZLE_X;
   case 'y':
   case 'g':
      return SWIZZLE_Y;
   case 'z':
   case 'b':
      return SWIZZLE_Z;
   case 'w':
   case 'a':
      return SWIZZLE_W;
   }

   return 0;
}

#define YY_USER_ACTION							\
   do {									\
      yylloc->first_column = yylloc->last_column;			\
      yylloc->last_column += yyleng;					\
      if ((yylloc->first_line == 1)					\
	  && (yylloc->first_column == 1)) {				\
	 yylloc->position = 1;						\
      } else {								\
	 yylloc->position += yylloc->last_column - yylloc->first_column; \
      }									\
   } while(0);

#define YY_EXTRA_TYPE struct asm_parser_state *
#line 1008 "lex.yy.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (yyscan_t yyscanner );

int yyget_debug (yyscan_t yyscanner );

void yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra (yyscan_t yyscanner );

void yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *yyget_in (yyscan_t yyscanner );

void yyset_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *yyget_out (yyscan_t yyscanner );

void yyset_out  (FILE * out_str ,yyscan_t yyscanner );

int yyget_leng (yyscan_t yyscanner );

char *yyget_text (yyscan_t yyscanner );

int yyget_lineno (yyscan_t yyscanner );

void yyset_lineno (int line_number ,yyscan_t yyscanner );

YYSTYPE * yyget_lval (yyscan_t yyscanner );

void yyset_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

       YYLTYPE *yyget_lloc (yyscan_t yyscanner );
    
        void yyset_lloc (YYLTYPE * yylloc_param ,yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (yyscan_t yyscanner );
#else
extern int yywrap (yyscan_t yyscanner );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  ,yyscan_t yyscanner);
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		unsigned n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param,YYLTYPE * yylloc_param ,yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

#line 137 "program_lexer.l"


#line 1252 "lex.yy.c"

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		yy_load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 675 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 955 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 139 "program_lexer.l"
{ return ARBvp_10; }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 140 "program_lexer.l"
{ return ARBfp_10; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 141 "program_lexer.l"
{
   yylval->integer = at_address;
   return_token_or_IDENTIFIER(require_ARB_vp, ADDRESS);
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 145 "program_lexer.l"
{ return ALIAS; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 146 "program_lexer.l"
{ return ATTRIB; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 147 "program_lexer.l"
{ return END; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 148 "program_lexer.l"
{ return OPTION; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 149 "program_lexer.l"
{ return OUTPUT; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 150 "program_lexer.l"
{ return PARAM; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 151 "program_lexer.l"
{ yylval->integer = at_temp; return TEMP; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 153 "program_lexer.l"
{ return_opcode(             1, VECTOR_OP, ABS, OFF); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 154 "program_lexer.l"
{ return_opcode(require_ARB_fp, VECTOR_OP, ABS, ZERO_ONE); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 155 "program_lexer.l"
{ return_opcode(             1, BIN_OP, ADD, OFF); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 156 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, ADD, ZERO_ONE); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 157 "program_lexer.l"
{ return_opcode(require_ARB_vp, ARL, ARL, OFF); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 159 "program_lexer.l"
{ return_opcode(require_ARB_fp, TRI_OP, CMP, OFF); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 160 "program_lexer.l"
{ return_opcode(require_ARB_fp, TRI_OP, CMP, ZERO_ONE); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 161 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, COS, OFF); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 162 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, COS, ZERO_ONE); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 164 "program_lexer.l"
{ return_opcode(             1, BIN_OP, DP3, OFF); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 165 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, DP3, ZERO_ONE); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 166 "program_lexer.l"
{ return_opcode(             1, BIN_OP, DP4, OFF); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 167 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, DP4, ZERO_ONE); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 168 "program_lexer.l"
{ return_opcode(             1, BIN_OP, DPH, OFF); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 169 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, DPH, ZERO_ONE); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 170 "program_lexer.l"
{ return_opcode(             1, BIN_OP, DST, OFF); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 171 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, DST, ZERO_ONE); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 173 "program_lexer.l"
{ return_opcode(             1, SCALAR_OP, EX2, OFF); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 174 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, EX2, ZERO_ONE); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 175 "program_lexer.l"
{ return_opcode(require_ARB_vp, SCALAR_OP, EXP, OFF); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 177 "program_lexer.l"
{ return_opcode(             1, VECTOR_OP, FLR, OFF); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 178 "program_lexer.l"
{ return_opcode(require_ARB_fp, VECTOR_OP, FLR, ZERO_ONE); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 179 "program_lexer.l"
{ return_opcode(             1, VECTOR_OP, FRC, OFF); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 180 "program_lexer.l"
{ return_opcode(require_ARB_fp, VECTOR_OP, FRC, ZERO_ONE); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 182 "program_lexer.l"
{ return_opcode(require_ARB_fp, KIL, KIL, OFF); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 184 "program_lexer.l"
{ return_opcode(             1, VECTOR_OP, LIT, OFF); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 185 "program_lexer.l"
{ return_opcode(require_ARB_fp, VECTOR_OP, LIT, ZERO_ONE); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 186 "program_lexer.l"
{ return_opcode(             1, SCALAR_OP, LG2, OFF); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 187 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, LG2, ZERO_ONE); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 188 "program_lexer.l"
{ return_opcode(require_ARB_vp, SCALAR_OP, LOG, OFF); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 189 "program_lexer.l"
{ return_opcode(require_ARB_fp, TRI_OP, LRP, OFF); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 190 "program_lexer.l"
{ return_opcode(require_ARB_fp, TRI_OP, LRP, ZERO_ONE); }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 192 "program_lexer.l"
{ return_opcode(             1, TRI_OP, MAD, OFF); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 193 "program_lexer.l"
{ return_opcode(require_ARB_fp, TRI_OP, MAD, ZERO_ONE); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 194 "program_lexer.l"
{ return_opcode(             1, BIN_OP, MAX, OFF); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 195 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, MAX, ZERO_ONE); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 196 "program_lexer.l"
{ return_opcode(             1, BIN_OP, MIN, OFF); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 197 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, MIN, ZERO_ONE); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 198 "program_lexer.l"
{ return_opcode(             1, VECTOR_OP, MOV, OFF); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 199 "program_lexer.l"
{ return_opcode(require_ARB_fp, VECTOR_OP, MOV, ZERO_ONE); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 200 "program_lexer.l"
{ return_opcode(             1, BIN_OP, MUL, OFF); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 201 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, MUL, ZERO_ONE); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 203 "program_lexer.l"
{ return_opcode(             1, BINSC_OP, POW, OFF); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 204 "program_lexer.l"
{ return_opcode(require_ARB_fp, BINSC_OP, POW, ZERO_ONE); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 206 "program_lexer.l"
{ return_opcode(             1, SCALAR_OP, RCP, OFF); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 207 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, RCP, ZERO_ONE); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 208 "program_lexer.l"
{ return_opcode(             1, SCALAR_OP, RSQ, OFF); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 209 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, RSQ, ZERO_ONE); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 211 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, SCS, OFF); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 212 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, SCS, ZERO_ONE); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 213 "program_lexer.l"
{ return_opcode(             1, BIN_OP, SGE, OFF); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 214 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, SGE, ZERO_ONE); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 215 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, SIN, OFF); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 216 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, SIN, ZERO_ONE); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 217 "program_lexer.l"
{ return_opcode(             1, BIN_OP, SLT, OFF); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 218 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, SLT, ZERO_ONE); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 219 "program_lexer.l"
{ return_opcode(             1, BIN_OP, SUB, OFF); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 220 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, SUB, ZERO_ONE); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 221 "program_lexer.l"
{ return_opcode(             1, SWZ, SWZ, OFF); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 222 "program_lexer.l"
{ return_opcode(require_ARB_fp, SWZ, SWZ, ZERO_ONE); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 224 "program_lexer.l"
{ return_opcode(require_ARB_fp, SAMPLE_OP, TEX, OFF); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 225 "program_lexer.l"
{ return_opcode(require_ARB_fp, SAMPLE_OP, TEX, ZERO_ONE); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 226 "program_lexer.l"
{ return_opcode(require_ARB_fp, SAMPLE_OP, TXB, OFF); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 227 "program_lexer.l"
{ return_opcode(require_ARB_fp, SAMPLE_OP, TXB, ZERO_ONE); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 228 "program_lexer.l"
{ return_opcode(require_ARB_fp, SAMPLE_OP, TXP, OFF); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 229 "program_lexer.l"
{ return_opcode(require_ARB_fp, SAMPLE_OP, TXP, ZERO_ONE); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 231 "program_lexer.l"
{ return_opcode(             1, BIN_OP, XPD, OFF); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 232 "program_lexer.l"
{ return_opcode(require_ARB_fp, BIN_OP, XPD, ZERO_ONE); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 234 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_vp, VERTEX); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 235 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, FRAGMENT); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 236 "program_lexer.l"
{ return PROGRAM; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 237 "program_lexer.l"
{ return STATE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 238 "program_lexer.l"
{ return RESULT; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 240 "program_lexer.l"
{ return AMBIENT; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 241 "program_lexer.l"
{ return ATTENUATION; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 242 "program_lexer.l"
{ return BACK; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 243 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, CLIP); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 244 "program_lexer.l"
{ return COLOR; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 245 "program_lexer.l"
{ return_token_or_DOT(require_ARB_fp, DEPTH); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 246 "program_lexer.l"
{ return DIFFUSE; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 247 "program_lexer.l"
{ return DIRECTION; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 248 "program_lexer.l"
{ return EMISSION; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 249 "program_lexer.l"
{ return ENV; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 250 "program_lexer.l"
{ return EYE; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 251 "program_lexer.l"
{ return FOGCOORD; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 252 "program_lexer.l"
{ return FOG; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 253 "program_lexer.l"
{ return FRONT; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 254 "program_lexer.l"
{ return HALF; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 255 "program_lexer.l"
{ return INVERSE; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 256 "program_lexer.l"
{ return INVTRANS; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 257 "program_lexer.l"
{ return LIGHT; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 258 "program_lexer.l"
{ return LIGHTMODEL; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 259 "program_lexer.l"
{ return LIGHTPROD; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 260 "program_lexer.l"
{ return LOCAL; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 261 "program_lexer.l"
{ return MATERIAL; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 262 "program_lexer.l"
{ return MAT_PROGRAM; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 263 "program_lexer.l"
{ return MATRIX; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 264 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, MATRIXINDEX); }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 265 "program_lexer.l"
{ return MODELVIEW; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 266 "program_lexer.l"
{ return MVP; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 267 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, NORMAL); }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 268 "program_lexer.l"
{ return OBJECT; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 269 "program_lexer.l"
{ return PALETTE; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 270 "program_lexer.l"
{ return PARAMS; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 271 "program_lexer.l"
{ return PLANE; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 272 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, POINT_TOK); }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 273 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, POINTSIZE); }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 274 "program_lexer.l"
{ return POSITION; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 275 "program_lexer.l"
{ return PRIMARY; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 276 "program_lexer.l"
{ return PROJECTION; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 277 "program_lexer.l"
{ return_token_or_DOT(require_ARB_fp, RANGE); }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 278 "program_lexer.l"
{ return ROW; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 279 "program_lexer.l"
{ return SCENECOLOR; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 280 "program_lexer.l"
{ return SECONDARY; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 281 "program_lexer.l"
{ return SHININESS; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 282 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, SIZE_TOK); }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 283 "program_lexer.l"
{ return SPECULAR; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 284 "program_lexer.l"
{ return SPOT; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 285 "program_lexer.l"
{ return TEXCOORD; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 286 "program_lexer.l"
{ return_token_or_DOT(require_ARB_fp, TEXENV); }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 287 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, TEXGEN); }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 288 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, TEXGEN_Q); }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 289 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, TEXGEN_S); }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 290 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, TEXGEN_T); }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 291 "program_lexer.l"
{ return TEXTURE; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 292 "program_lexer.l"
{ return TRANSPOSE; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 293 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, VTXATTRIB); }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 294 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, WEIGHT); }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 296 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, TEXTURE_UNIT); }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 297 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, TEX_1D); }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 298 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, TEX_2D); }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 299 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, TEX_3D); }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 300 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, TEX_CUBE); }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 301 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_rect, TEX_RECT); }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 302 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_shadow, TEX_SHADOW1D); }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 303 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_shadow, TEX_SHADOW2D); }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 304 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_shadow && require_rect, TEX_SHADOWRECT); }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 305 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_texarray, TEX_ARRAY1D); }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 306 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_texarray, TEX_ARRAY2D); }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 307 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_shadow && require_texarray, TEX_ARRAYSHADOW1D); }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 308 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_shadow && require_texarray, TEX_ARRAYSHADOW2D); }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 310 "program_lexer.l"
{
   yylval->string = strdup(yytext);
   return IDENTIFIER;
}
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 315 "program_lexer.l"
{ return DOT_DOT; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 317 "program_lexer.l"
{
   yylval->integer = strtol(yytext, NULL, 10);
   return INTEGER;
}
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 321 "program_lexer.l"
{
   yylval->real = _mesa_strtod(yytext, NULL);
   return REAL;
}
	YY_BREAK
case 156:
/* rule 156 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 325 "program_lexer.l"
{
   yylval->real = _mesa_strtod(yytext, NULL);
   return REAL;
}
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 329 "program_lexer.l"
{
   yylval->real = _mesa_strtod(yytext, NULL);
   return REAL;
}
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 333 "program_lexer.l"
{
   yylval->real = _mesa_strtod(yytext, NULL);
   return REAL;
}
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 338 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_NOOP;
   yylval->swiz_mask.mask = WRITEMASK_XYZW;
   return MASK4;
}
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 344 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_XY
      | mask_from_char(yytext[3]);
   return MASK3;
}
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 350 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_XZW;
   return MASK3;
}
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 355 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_YZW;
   return MASK3;
}
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 361 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_X
      | mask_from_char(yytext[2]);
   return MASK2;
}
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 367 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_Y
      | mask_from_char(yytext[2]);
   return MASK2;
}
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 373 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_ZW;
   return MASK2;
}
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 379 "program_lexer.l"
{
   const unsigned s = swiz_from_char(yytext[1]);
   yylval->swiz_mask.swizzle = MAKE_SWIZZLE4(s, s, s, s);
   yylval->swiz_mask.mask = mask_from_char(yytext[1]);
   return MASK1; 
}
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 386 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = MAKE_SWIZZLE4(swiz_from_char(yytext[1]),
					    swiz_from_char(yytext[2]),
					    swiz_from_char(yytext[3]),
					    swiz_from_char(yytext[4]));
   yylval->swiz_mask.mask = 0;
   return SWIZZLE;
}
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 395 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_NOOP;
   yylval->swiz_mask.mask = WRITEMASK_XYZW;
   return_token_or_DOT(require_ARB_fp, MASK4);
}
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 401 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_XY
      | mask_from_char(yytext[3]);
   return_token_or_DOT(require_ARB_fp, MASK3);
}
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 407 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_XZW;
   return_token_or_DOT(require_ARB_fp, MASK3);
}
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 412 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_YZW;
   return_token_or_DOT(require_ARB_fp, MASK3);
}
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 418 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_X
      | mask_from_char(yytext[2]);
   return_token_or_DOT(require_ARB_fp, MASK2);
}
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 424 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_Y
      | mask_from_char(yytext[2]);
   return_token_or_DOT(require_ARB_fp, MASK2);
}
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 430 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_ZW;
   return_token_or_DOT(require_ARB_fp, MASK2);
}
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 436 "program_lexer.l"
{
   const unsigned s = swiz_from_char(yytext[1]);
   yylval->swiz_mask.swizzle = MAKE_SWIZZLE4(s, s, s, s);
   yylval->swiz_mask.mask = mask_from_char(yytext[1]);
   return_token_or_DOT(require_ARB_fp, MASK1);
}
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 444 "program_lexer.l"
{
   if (require_ARB_vp) {
      return TEXGEN_R;
   } else {
      yylval->swiz_mask.swizzle = MAKE_SWIZZLE4(SWIZZLE_X, SWIZZLE_X,
						SWIZZLE_X, SWIZZLE_X);
      yylval->swiz_mask.mask = WRITEMASK_X;
      return MASK1;
   }
}
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 455 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = MAKE_SWIZZLE4(swiz_from_char(yytext[1]),
					    swiz_from_char(yytext[2]),
					    swiz_from_char(yytext[3]),
					    swiz_from_char(yytext[4]));
   yylval->swiz_mask.mask = 0;
   return_token_or_DOT(require_ARB_fp, SWIZZLE);
}
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 464 "program_lexer.l"
{ return DOT; }
	YY_BREAK
case 179:
/* rule 179 can match eol */
YY_RULE_SETUP
#line 466 "program_lexer.l"
{
   yylloc->first_line++;
   yylloc->first_column = 1;
   yylloc->last_line++;
   yylloc->last_column = 1;
   yylloc->position++;
}
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 473 "program_lexer.l"
/* eat whitespace */ ;
	YY_BREAK
case 181:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 474 "program_lexer.l"
/* eat comments */ ;
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 475 "program_lexer.l"
{ return yytext[0]; }
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 476 "program_lexer.l"
ECHO;
	YY_BREAK
#line 2384 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 675 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 675 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 674);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp , yyscan_t yyscanner)
{
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = yyg->yy_n_chars + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf ,yyscanner );

	yyfree((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	int num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_lineno called with no buffer" , yyscanner); 
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_column called with no buffer" , yyscanner); 
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void yyset_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */

int yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 476 "program_lexer.l"



void
_mesa_program_lexer_ctor(void **scanner, struct asm_parser_state *state,
			 const char *string, size_t len)
{
   yylex_init_extra(state,scanner);
   yy_scan_bytes(string,len,*scanner);
}

void
_mesa_program_lexer_dtor(void *scanner)
{
   yylex_destroy(scanner);
}

